<?php

namespace Drupal\db_queries\EventSubscriber;

use Drupal\Core\Database\Event\StatementExecutionEndEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\Event\ResponseEvent;
use Symfony\Component\HttpKernel\KernelEvents;

/**
 * Subscribes to the kernel request event to register a shutdown function.
 */
class DbQueriesEventSubscriber implements EventSubscriberInterface {

  /**
   * Implements EventSubscriberInterface::getSubscribedEvents().
   *
   * @return array
   *   An array of event listener definitions.
   */
  public static function getSubscribedEvents(): array {

    return [
      StatementExecutionEndEvent::class => ['onStatementExecutionEnd'],
      KernelEvents::REQUEST => ['onRequest', -100],
    ];

  }

  /**
   * Register db_queries_shutdown function.
   *
   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   The event to process.
   */
  public function onRequest(RequestEvent $event) {
    drupal_register_shutdown_function('db_queries_shutdown');
  }

  /**
   * Collects data for the current request.
   */
  public function onStatementExecutionEnd(StatementExecutionEndEvent $event): void {

    $queryCount = &drupal_static('db_query');

    if(empty($queryCount)) {
      $queryCount = 0;
    }

    $queryCount++;
  }

}
